/**
 * The KoboldUnderwear class represents a piece of underwear tailor-made for kobolds that can be worn by the protagonist.
 */
function KoboldUnderwear() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Kobold Underwear";
    var itemDescription = "Proper underwear, made to fit a kobold. Unisex, but looks better on boys. Covers both ends.";
    var baseValue = 6;
    var offensiveValue = 0;
    var defensiveValue = 0;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.KOBOLDUNDERWEAR;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.GEAR;
    // GEAR-REQUIRED slot-enum.
    this.slot = SlotEnum.UNDERWEAR;

    // What this underwear is stained with.
    this.isStainedWith = "";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        if (that.stained()) {
            var built = that.isStainedWith + "-stained " + itemName;
            var toReturn = caps ? built : built.toLowerCase();
            return toReturn;
        } else {
            var toReturn = caps ? itemName : itemName.toLocaleLowerCase();
            return toReturn;
        }
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        var toReturn = that.stained() ? itemDescription + " Stinks like " + that.isStainedWith + "." : itemDescription;
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        var calculatedPrice = that.stained() ? baseValue - 1 : baseValue;
        return calculatedPrice;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        if (!that.stained()) {
            return "width: 220px;";
        } else {
            return "width: 250px;";
        }
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the offensive value of this piece of gear.
     * @returns {int} The offensive value of this piece of gear.
     */
    this.offence = function () {
        return offensiveValue;
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the defensive value of this piece of gear.
     * @returns {int} The defensive value of this piece of gear.
     */
    this.defence = function () {
        return defensiveValue;
    };

    /**
     * UNDERWEAR-required function.
     * Stains the underwear.
     * @param {string} what What the underwear gets stained with. Should always start with a capital letter.
     */
    this.stain = function (what) {
        that.isStainedWith = what;
    };

    /**
     * UNDERWEAR-required function.
     * Returns true if the underwear is stained, and false otherwise.
     * @returns {boolean} True if the underwear is stained, and false otherwise.
     */
    this.stained = function () {
        return that.isStainedWith !== "";
    };

    /**
     * UNDERWEAR-required function.
     * Returns what the underwear is stained with.
     * @returns {string} What the underwear is stained with.
     */
    this.stainedWith = function () {
        return that.isStainedWith;
    };

    /**
     * UNDERWEAR-required function.
     * Cleans the underwear, removing any stains.
     */
    this.clean = function () {
        that.isStainedWith = "";
    };

    /**
     * UNDERWEAR-required function.
     * Returns true if the underwear covers the groin, and false otherwise.
     * @returns {boolean} True if the underwear covers the groin, and false otherwise.
     */
    this.coversGroin = function () {
        return true;
    };

    /**
     * UNDERWEAR-required function.
     * Returns true if the underwear covers the rear, and false otherwise.
     * @returns {boolean} True if the underwear covers the rear, and false otherwise.
     */
    this.coversRear = function () {
        return true;
    };
    
    /**
     * UNDERWEAR-required function.
     * Returns true if the underwear is skimpy, and false otherwise.
     * @returns {boolean} True if the underwear is skimpy, and false otherwise.
     */
    this.skimpy = function () {
        return false;
    };

    /**
     * UNDERWEAR-required function.
     * Returns true if the underwear can be torn, and false otherwise.
     * @returns {boolean} True if the underwear can be torn, and false otherwise.
     */
    this.canBeTorn = function () {
        return true;
    };

    /**
     * UNDERWEAR-required function.
     * Returns true if the underwear is a mismatch for the kobold's current gender.
     * @returns {boolean} True if the underwear is a mismatch for the kobold's current gender, false otherwise.
     */
    this.wrongGender = function () {
        return false; // Unisex.
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {KoboldUnderwear-stripped} underwear A KoboldUnderwear object, stripped of private members and all functions.
     */
    this.load = function (underwear) {
        that.isStainedWith = underwear.isStainedWith;
    };
}
