/**
 * Class capable of exporting single saves or entire save lists to file.
 */
function SaveExporter() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;


    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Constructs an appropriate save name.
     * @param {boolean} all Whether this concerns all saves or not.
     * @param {int} slot The specific slot of the save, in case this does not concern all saves.
     * @returns {string} The save name.
     */
    function constructSaveName(all, slot) {
        if (all) {
            return `savelist.kas`;
        }
        slot = slot || 0;
        slot++;
        return `save${slot}.kas`;
    }

    /**
     * Downloads the passed text as a file with the given filename.
     * @param {string} filename The default filename.
     * @param {string} text The file's contents.
     */
    function download(filename, text) {
        var element = document.createElement('a');
        element.setAttribute('href', 'data:text/plain;charset=utf-8,' + encodeURIComponent(text));
        element.setAttribute('download', filename);
        element.style.display = 'none';
        document.body.appendChild(element);
        element.click();
        document.body.removeChild(element);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Exports a single save slot to a file and prompts download thereof.
     * @param {int} slot The save slot to export.
     */
    this.slot = function (slot) {
        var json = global.saveManager.slotToJson(slot);
        var jsonArray = "[" + json + "]";
        var fileName = constructSaveName(false, slot);
        download(fileName, jsonArray);
    };

    /**
     * Exports all the save slots to a file and prompts download thereof.
     */
    this.all = function () {
        var saveList = global.saveManager.saveList();
        var jsonArray = "[";
        for (var i in saveList) {
            var slot = saveList[i].slot;
            var json = global.saveManager.slotToJson(slot);
            jsonArray += json + ",";
        }
        if (saveList.length) { // Remove trailing comma if necessary.
            jsonArray = jsonArray.substring(0, jsonArray.length - 1);
        }
        jsonArray += "]";
        var fileName = constructSaveName(true, false);
        download(fileName, jsonArray);
    };
}

