/**
 * Controls a loading bar which may be hidden and shown at will.
 */
function LoadBar() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var curr = 0;
    var max = 100;
    var id = "loadbar";
    var innerId = "loadbarinner";
    var absoluteId = "loadbarabsolute";
    var relativeId = "loadbarrelative";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Updates the relative part of the load bar.
     */
    function updateRelative() {
        var percent = Math.round((curr / max) * 100);
        $("#" + relativeId).html(percent + "%");
    }

    /**
     * Updates the absolute part of the load bar.
     */
    function updateAbsolute() {
        $("#" + absoluteId).html(curr + "/" + max);
    }

    /**
     * Updates the bar of the load bar.
     */
    function updateBar() {
        var percent = Math.round((curr / max) * 100);
        $("#" + innerId).attr('style', `width: ${percent}%`);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Shows the loadbar.
     * @param {int} total How many things need to be loaded.
     */
    this.show = function (total) {
        max = total;
        that.update(total);
        $("#" + id).fadeIn(400);
    };

    /**
     * Initializes the load bar with the total amount of things to load.
     * @param {int} remaining How many things still need to be loaded.
     */
    this.update = function (remaining) {
        curr = max - remaining;
        updateRelative();
        updateAbsolute();
        updateBar();
    };

    /**
     * Hides the loadbar.
     */
    this.hide = function () {
        that.update(0);
        $("#" + id).stop();
        $("#" + id).fadeOut(400);
    };
}
