/**
 * Arrival section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoRest(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoArrivalChoice.REST;
    var reqController = ctrl.arrival;
    var subController = ctrl.preBlackmail;
    var changeController = ctrl.preBlackmail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.proposition;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;
        var bindings = !global.kobold.history.shared.enslavement.nightOne.escapedBindings;

        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            toReturn += `[p]
                            You wearily roll over onto your side, hiding your visage from the beaming sunlight, letting it warm your back instead.
                            Despite having been out for what you can only presume to be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] you passed out.
                            You could use a few extra hours of peace and quiet.
                            You can worry about escaping this cell later.
                        [/p]
                        [p]
                            Right as you could feel reality starting to slip away once again,
                            a subtle [i]click[/i] resonates throughout your cell.
                            The wooden door widly swings open, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] sinking into your skull, worsening your killer headache.
                            Footsteps.
                            Your half-conscious mind distantly realizes someone is entering the cart.
                        [/p]
                        [p]
                            [big][color=gblue][b]Rise and shine, slave![/b][/color][/big]
                        [/p]
                        [p]
                            The booming voice is [b]agonizingly[/b] loud,
                            your head feeling like it's about to [b]burst[/b].
                            ${bindings ? `You instinctively try to move your hands to your forehead,
                            but find them still bound from the night before.` : `You instinctively move your hands to your forehead
                            to [b]try[/b] to cope with the horrible sensation.`}
                            Your heavy eyelids slowly open.
                            In your blurry vision you can see a pair of grey-furred feet standing in the doorway.
                            You slept so poorly, you almost feel like you have a bad hangover.
                        [/p]
                        [p]
                            You try to [b]beg[/b] for just a few more minutes of rest, but nothing intelligent escapes your muzzle.
                            Instead, you let out a mixture between a whine, a groan and a growl.
                            "[color=gblue]I said [b]get up[/b], lizard.[/color]" the wolf repeats.
                            In an effort to force you awake, he repeatedly bangs his foot against the floor,
                            unknowingly [b]torturing[/b] your sleep-deprived brain.
                        [/p]
                        [p]
                            Almost reduced to tears from the intense pain, your aching mind snaps to life.
                            While your sight is still hazy, you open your eyes further, and tilt your gaze up to meet his.
                            Fenrir.
                            That was his name.
                            The wolf that caught you the other day.
                            And he's [i]naked[/i], this time around.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        } else {
            toReturn += `[p]
                            You wearily roll over onto your side, hiding your visage from the beaming sunlight, letting it warm your back instead.
                            Despite having slept for what you can only presume be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] you passed out.
                            You could use a few extra hours of peace and quiet.
                            You can worry about escaping this cell later.
                        [/p]
                        [p]
                            Right as you could feel reality starting to slip away once again,
                            a subtle [i]click[/i] resonates throughout your cell.
                            The wooden door widly swings open, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] piercing your unconsciousness, worsening your headache.
                            Footsteps.
                            Your half-asleep mind distantly realizes someone is entering the cart.
                        [/p]
                        [p]
                            [big][color=gblue][b]Rise and shine, slave![/b][/color][/big]
                        [/p]
                        [p]
                            The booming voice is [b]agonizingly[/b] loud,
                            your head feeling like worse with every passing second.
                            You instinctively try to move your hands to your forehead,
                            but find them still bound from the night before.
                            Your heavy eyelids slowly open.
                            In your blurry vision you can see a pair of grey-furred feet standing in the doorway.
                            You slept so poorly, you almost feel like you have a hangover.
                        [/p]
                        [p]
                            You try to [b]beg[/b] for just a few more minutes of rest, but nothing intelligent escapes your muzzle.
                            Instead, you let out a mixture between a whine, a groan and a growl.
                            "[color=gblue]I said [b]get up[/b], lizard.[/color]" the wolf repeats.
                            In an effort to force you awake, he repeatedly bangs his foot against the floor,
                            unknowingly [b]torturing[/b] your sleep-deprived brain.
                        [/p]
                        [p]
                            Almost reduced to tears from the intensifying pain, your aching mind snaps to life.
                            While your sight is still hazy, you open your eyes a further, and tilt your gaze up to meet his.
                            Fenrir.
                            That was his name.
                            The wolf that caught you the other day.
                            And he's [i]naked[/i], this time around.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
