/**
 * Claw section of the unknown scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestUnknownClaw(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `clawContinueButton`;
    
    var next = new ForestUnknownClawContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your mind races to come up with a [i]way out[/i].
                            You try to tug against the plant's grasp once more, but it simply won't budge, and you'll end up hurting yourself if you continue to resist it.
                            With the other spiked tentacles inching ever closer, you figure that if the tendril won't let go, you'll just have to [i]slice it off[/i] instead.
                        [/p]
                        [p]
                            The organic terror may have restrained [i]one[/i] of your wrists, but [b]not[/b] both of them!
                            Gritting your teeth and steeling your resolve, you firmly yank your grasped arm back one final time.
                            The spikes around your wrist sink into your flesh, drawing a small amount of blood,
                            but the pain is a small price to pay for fully stretching the tendril,
                            preparing the rope-like plant part for a well-aimed slicing swipe from your razor-sharp claws.
                        [/p]
                        [p]
                            The strain from your tug pulling the tendril taut, your claws cut through it with ease,
                            your arm freed as the severed appendage limply falls to the ground.
                            The tentacle monster seems to recoil for a moment, as though hurt.
                            It was probably expecting a defenceless human maiden to walk into its trap instead of a crafty kobold such as yourself.
                        [/p]
                        [p]
                            With the thornbush receding, you briefly entertain the thought that you [i]won[/i] this battle.
                            Within moments, however, the plant already seems to have recovered from the loss of one of its graspers, and it begins its assault anew.
                            You barely dodge a second lunging tentacle trying to snag your non-bleeding wrist, 
                            and it is at that point you decide to [b]get the hell out of there[/b] while you still can.                           
                        [/p]
                        [p]
                            Reaching downwards, you quickly grab your ${global.kobold.inventory.createItemWithTooltip(new WoolSweater())} off the ground.
                            You're not leaving here without it, else this entire ordeal would have been for nothing!
                            You hop backwards to evade yet another springing tendril, yet accidentally step on one of them, small thorns digging into your rather soft sole.
                            Biting through the stinging pain, you turn around and [b]sprint[/b] away as fast as you can, 
                            a final tentacle lashing your back, yet failing to grab you as you bolt away from the animated thornbush.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.unknown.pry.claw.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unknown.pry.claw.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "forestUnknownClaw";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unknown.pry.base.get() !== ForestUnknownPryChoice.CLAW) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unknown.pry.claw.change();
        part += buildChoice();
        part += next.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unknown.pry.base.get() !== ForestUnknownPryChoice.CLAW) {
            return;
        }
        
        next.registerListeners();
        
        if (ctrl.unknown.pry.claw.continued()) {
            return;
        }

        registerContinueListener();
    };
}
