/**
 * Stay still section of the unknown scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestUnknownStayStill(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var suckId = "unknownSuckButton";
    var biteId = "unknownStillBiteButton";

    var toSuck = new ForestUnknownSuck(ctrl);
    var toBite = new ForestUnknownBite(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.deepwoods.tentaclePlant.sapKnowledge = true;
        var toReturn = `[p]
                            You freeze up.
                            You don't move, not even an inch.
                            Maybe the bush thinks you're a threat.
                            Or maybe it can't see you unless you're moving.
                            Perhaps, if you stay perfectly still, the plant will just let you go.
                        [/p]
                        [p]
                            Sadly, you are mistaken.
                            Instead of releasing the grip on your wrist, more thorny vines wrap around your other limbs.
                            Two of them simultaneously snake onto your ankles, keeping your legs in place by the threat of puncturing your scales with thick thorns.
                            Another tendril wraps around your already-restricted arm, reinforcing the creature's hold on it.
                            Your free arm, too, gets snagged by one of the thorny appendages, leaving you completely immobilized, save for your head and your tail.
                        [/p]
                        [p]
                            Your resolve is wavering, yet still, you convince yourself that if you just remain calm, 
                            and not start pointlessly struggling against your spiky restraints, everything will work out [i]just fine[/i].
                            Plants don't eat meat, [i]you hope[/i], so as long as you don't [i]fight[/i] the monstrosity before you, 
                            surely it will have no reason whatsoever to [i]hurt you[/i], right?
                        [/p]
                        [p]
                            The central mass of the hulking monster slowly creeps closer, until it is barely a foot away from your fully restricted body.
                            As it stops, a single tentacle slips out from underneath the thorny exterior, one very much so [i]unlike[/i] the others.
                            While the other tendrils are covered in spikes and brambles, this one is perfectly [i]smooth[/i].
                            In fact, it appears [i]slick[/i], almost [i]shiny[/i], as though covered in a viscous liquid of some sort.
                            In color, too, it differs from the rest.
                            While the normal vines are a brownish green, this one is far more [b]vibrant[/b], a bright shade of green, borderline unnatural.
                        [/p]
                        [p]
                            It slowly slithers over the ground, towards your feet, before rising upwards, once again acting like a snake, this time one being charmed.
                            The long, slick tentacle lifts itself all the way up to your face, hovering directly in front of you.
                            It smells sickly sweet, like an exotic kind of honey you once stole a jar of.
                            Getting a closer look, you notice a small opening at the very tip of the oddly shaped plant-part, like a plant bud that hasn't bloomed yet.
                            Oozing from it at a steady pace is the same thick liquid you assume covers the rest the appendage's length.
                        [/p]
                        [p]
                            The tendril nears your face, hovering directly in front of your muzzle, mere inches away from your snout.
                            Then, it squirts a hefty rope of the sticky, golden-brown goo across your muzzle, 
                            splattering atop your scales all the way from the tip of your nose to in between your eyes.
                            A mouth-watering, overly-dominant fragrance of sheer honeyed [b]sweetness[/b] wafts from the syrupy substance,
                            completely [b]clogging[/b] your nostrils, filling up your lungs and clouding your mind.
                            It smells [b]so good[/b], it makes you want to [b]taste[/b] it.
                        [/p]
                        [p]
                            Just as you were about to open your mouth to try and snake your tongue to the top of your muzzle in an attempt to sample the goop,
                            the tentacle presses its tip against your lips.
                            It seductively drags itself from one side of your muzzle to the other, leaving a trail of mind-altering honey in its wake.
                            If you want to taste it, all you have to do is open your mouth and lick your lips.
                            Heck, why stop there?
                            Why not [b]suck[/b] the syrup directly from the tentacle,
                            so you can relish in as much of the undoubtedly [b]heavenly[/b] flavour as you could ever want?
                        [/p]
                        [p]
                            As though the monstrosity can read your mind,
                            the tendril positions itself at the front-end of your muzzle,
                            and slowly begins to press into your mouth.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSuckChoice() {
        var disabled = ctrl.unknown.pry.stay.has() ? "disabled" : "";
        var isSelected = ctrl.unknown.pry.stay.get() === ForestUnknownStayStillChoice.SUCK;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${suckId}" ${disabled}>Suck it</button>`;

        var tooltip = global.parser.parse(`You can't resist. You [b]need[/b] to know how it tastes.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the shake choice button.
     */
    function buildBiteChoice() {
        var disabled = ctrl.unknown.pry.stay.has() ? "disabled" : "";
        var isSelected = ctrl.unknown.pry.stay.get() === ForestUnknownStayStillChoice.BITE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${biteId}" ${disabled}>Bite it</button>`;

        var tooltip = global.parser.parse(`Don't give in. No matter how enticing it may be, there's no telling what that goop might do to you!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildSuckChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildBiteChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + suckId), $("#" + biteId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerSuckListener() {
        $("#" + suckId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unknown.pry.stay.set(ForestUnknownStayStillChoice.SUCK);
            loadNextPart(toSuck);
        });

    }

    /**
     * Adds a listener to the button.
     */
    function registerBiteListener() {
        $("#" + biteId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unknown.pry.stay.set(ForestUnknownStayStillChoice.BITE);
            loadNextPart(toBite);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "forestUnknownStayStill";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unknown.pry.base.get() !== ForestUnknownPryChoice.STILL) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unknown.pry.stay.change();
        part += buildChoice();
        part += toBite.build();
        part += toSuck.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unknown.pry.base.get() !== ForestUnknownPryChoice.STILL) {
            return;
        }

        toBite.registerListeners();
        toSuck.registerListeners();

        if (ctrl.unknown.pry.stay.has()) {
            return;
        }

        registerSuckListener();
        registerBiteListener();
    };
}

var ForestUnknownStayStillChoice = {
    SUCK: 1,
    BITE: 2
};
