/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseFollow(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    
    var nextId = arguments.callee.name + "ButtonOne";

    var next = new FarmerHouseFollowRun(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You doubt the cupboard'll contain much of interest.
                            The best stuff is probably scattered throughout the house.
                            Who puts all their eggs in one basket, right?
                            Hopefully not these humans.
                        [/p]
                        [p]
                            You sneak into the kitchen and peek around the corner.
                            The housewife, as you expected, has just finished setting up the small, round table for dinner.
                            Three metallic plates and two sandwiches, one of which is cut in half and distributed over two plates.
                            The family's meagre meal set up, the human steps out into the living room, closing the loudly creaking,
                            half-crooked dining room door behind her.
                            Must not be dinnertime yet.
                        [/p]
                        [p]
                            Darnit.
                            While you [i]do[/i] like having a solid surface in between you and the housewife,
                            the wooden door she shut bars your way to the rest of the house.
                            Once again, your plans are foiled and your progress is hampered.
                            You figure it's too late to back out now.
                            Best to grab what you can and get the hell out of this place.
                        [/p]
                        [p]
                            You scour the kitchen, looking for anything of value to take.
                            The counter is barren, apart from some basic, well-worn tools.
                            The small coal-oven underneath looks like it hasn't been used in [b]months[/b].
                            The coal-prod is too rusted to be of any use, and there aren't even any spices like salt or pepper around.
                            The woman took the bread along with her when she left this part of the house, leaving absolutely [b]nothing[/b] for you to steal.
                        [/p]
                        [p]
                            Annoyed, you step into the dining room.
                            Through the cracks of the door, you can see the woman brushing the floor on the other side.
                            This room contains naught but a single, kobold-sized cupboard and the table set for dinner.
                            You quietly rummage through the cupboard.
                            Nothing but worthless metal dishes, only the fanciest of which are made of iron.
                            Not even a blacksmith would pay a single coin for low-grade copper and bronze.
                        [/p]
                        [p]
                            The cutlery on the table, too, is exceedingly supbar.
                            That leaves just one option: the food itself.
                            The full-sized sandwich and its two smaller siblings are smeared with some kind of butter, upon which rests a thick slice of ham.
                            Your mouth waters just [b]thinking[/b] about the taste of an actual [b]meal[/b].
                            While you might not be able to sell the food for much, at least you'll have gained [i]something[/i] out this adventure.
                        [/p]
                        [p]
                            The moral implications of stealing from an obviously poor family, 
                            who may or may not have a child, as indicated by the third plate, come to mind for a moment.
                            You figure that if they had enough food to prepare [b]one[/b] meal, you're certain they'll have plenty to make a second one.
                            Plus, you've gone for [b]way[/b] longer than a single day without eating in the past.
                            You're certain it won't kill them to miss out on a couple of slices of bread and ham.
                        [/p]
                        [p]
                            While the allure of digging in and having a feast right here and now is great, you know better than to linger when trespassing.
                            You'll have to save these for later.
                            You grab the large sandwich, and both of the smaller ones, and pocket them.
                            While you'd have liked to get a lot more loot out of this place, you'll take what you can get.
                            You silently slip out through the back door from whence you came.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.follow.continued() ? "disabled" : "";
        var isSelected = ctrl.follow.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${nextId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + nextId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + nextId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.follow.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if(ctrl.inside.get() !== FarmerHouseInsideChoice.FOLLOW) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.follow.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if(ctrl.inside.get() !== FarmerHouseInsideChoice.FOLLOW) {
            return;
        }
        
        next.registerListeners();

        if (ctrl.follow.continued()) {
            return;
        }

        registerNextListener();
    };
}
