/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellScrape(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.scrape;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.scrapedThigh = true;
        var drank = global.kobold.history.shared.well.drankWater;
        var drowned = global.kobold.history.shared.well.drowned;
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var arrivalDescriptor = `You may not have wanted to go down this damp hole, but now that you're here, you might as well explore it fully.`;
        if (wanted) {
            arrivalDescriptor = `You wanted to explore this place, and you're not going to back down just because the air in here is a little stale.`;
            if (rocky) {
                arrivalDescriptor = `Your entrance might not have been very [i]graceful[/i], `;
                arrivalDescriptor += `but you're not going to let a single small setback dissuade you from properly exploring this damp hole.`;
            }
        }
        var toReturn = `[p]
                            You don't concern yourself with escaping the well just yet.
                            ${arrivalDescriptor}
                            You take a few deep breaths, filling your ${drowned ? `still slightly aching` : ``} lungs with as much air as they can possibly hold.
                            Steeling your nerves, you dip your head
                            underwater${rocky ? ` yet again` : ``}${drowned ? `, your mind working overtime to suppress flashbacks
                            from your near-death experience just a few minutes ago` : ``}.
                            Athletically lifting the lower half of your body upwards, while simultaneously sinking your torso deeper,
                            you dive down and submerge yourself completely.
                        [/p]
                        [p]
                            With your eyes having adapted to the dark, and all kobolds luckily being able to see underwater,
                            you immediately notice something dinstinctly [b]shiny[/b] at the bottom of the well.
                            Coins, perhaps?
                            Maybe ${wanted ? `coming down here wasn't such a bad idea after all` : `falling down here wasn't such a bad thing after all`}.
                        [/p]
                        [p]
                            You swim down further, until you suddenly feel a sharp, stinging [b]pain[/b] at the side of your leg.
                            Looking upwards, you find out that your thigh accidentally rubbed along a sharp rock protruding
                            from the edge of the well${rocky ? `, one you were lucky enough to miss on your earlier way down, ` : ``} without you noticing.
                            Blood flows liberally from your upper leg, painting part of the water an ever-darkening shade of red.
                            It seems that the pain is only now starting to fully set in.
                            You clutch your thigh, wincing and letting out an underwater [b]scream[/b] out of sheer pain.
                        [/p]
                        [p]
                            You were so focussed on the promise of gold that you momentarily forgot you're swimming around in a decrepit, age-old well.
                            You don't think the people that made this thing were too concerned about kobolds swimming around in it thousands of years in the future.
                            Money be damned, your leg hurts [b]far[/b] too much to continue downwards.
                            Making sure to avoid hitting the same sharp stone again, you flip yourself upright once more, and swim back up to the surface.
                        [/p]
                        [p]
                            Surfacing from your dive, you take a closer look at the wound you sustained.
                            It's a pretty [i]lengthy[/i] gash, running along the upper half of your outer thigh towards your rear,
                            stopping inches before reaching your butt proper.
                            While you don't think it's a very [i]deep[/i] cut, you're still bleeding like a stuck pig,
                            tainting the clear, ${drank ? `sedating` : `fresh`} water with kobold blood.
                        [/p]
                        [p]
                            As if to make matters even worse, a loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
