/**
 * Fight section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveDefenceLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;
    var changeController = ctrl.defenceLeave;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            With the basilisk no longer around, you take a closer look at your aching hand.
                            One of your fingers is all kinds of [b]fucked up[/b].
                            While you don't think it [b]broke[/b], it's definitely [b]dislocated[/b].
                            You've had this happen once before, a few years back when you fell out of a tree.
                            There's only one way to fix this, and it isn't pretty.
                        [/p]
                        [p]
                            Dreading what is to come, you gingerly take hold of the awkwardly-angled digit.
                            It hurts just to [b]touch[/b] it.
                            Come on, ${name}, you have to be [b]brave[/b].
                            You need to fix this [b]right now[/b], or it'll only get worse.
                            You close your eyes.
                            You grit your teeth.
                            You can do this.
                            Just think about something else.
                        [/p]
                        [p]
                            [big]
                                [color=red][b]SNAP[/b][/color]
                            [/big]
                        [/p]
                        [p]
                            With one firm yank, you [b]tug[/b] your dislocated finger back into place,
                            your bones agonizingly [b]grinding[/b] against one another before coming to rest in their normal position.
                            You [b]scream[/b] out in pain, your shriek echoing throughout the cavern as you collapse to your knees.
                            Tears drip down onto the stone floor below.
                            It hurt [b]so[/b] much.
                            You are hyperventilating.
                            The sickening snapping sound it made is [b]burned[/b] into your mind.
                            You feel like you're about to throw up.
                        [/p]
                        [p]
                            Holding your fixed hand by the wrist, you inspect it anew through your teary vision.
                            Your finger seems to be in its correct position once more.
                            You can painfully move it, but you'd prefer to keep it still right now.
                            You swallow deeply.
                            Your breathing stabilizes.
                            The worst of the pain is over.
                        [/p]
                        [p]
                            You slowly rise to your feet.
                            While still hurting, you need to get out of here, before the monster comes back for a second round.
                            You start walking alongside the water, hoping it'll lead you to an exit.
                            You go as fast as you can without falling down, the terrain uneven and cluttered with various stalagmites and rocks.
                            Ever so often, you stop to test your finger, but never for more than a couple of seconds.
                        [/p]
                        [p]
                            Before long, daylight comes into view.
                            As you expected: it was a stale branch of the river.
                            Climbing out of the cave, you sit your weary butt down on the riverside dirt, and take a breather.
                            You feel like you've earned one.
                            You can move your finger again, somewhat, but it'll need a bit more time before it stops aching completely.
                        [/p]
                        [p]
                            You've defied death more than once today.
                            You should consider yourself lucky to be alive.
                            The trip into the well was a harrowing experience.
                            You nearly got crushed, almost drowned, and ended up punching a basilisk in the face.
                            How many kobolds can say they did that?
                            Probably not a lot, since even your kind isn't dumb enough to hit a mythological rock monster without putting on a pair of steel gloves first.
                        [/p]
                        [p]
                            You've gained a few awesome stories to tell once you've grown old and wise.
                            Stories like the ones Seki used to tell you when you were little.
                            You went through all that trouble to get your mind off of him, and here you are reminiscing once more.
                            You just can't help yourself from clinging to times long gone.
                            Things were so much simpler back then.
                            You miss those days.
                        [/p]
                        [p]
                            The sun is slowly starting to set.
                            You drag yourself to your feet.
                            It's time to go.
                            Varanar isn't [i]that[/i] far off.
                            If your legs don't give out from underneath you, you might still make it there before nightfall.
                            And hopefully your finger'll have healed a bit more by then.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
