/**
 * Fight section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveLetGoLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;
    var changeController = ctrl.letGoLeave;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You and the basilisk slake your thirst, communally lapping at the cool water for nearly an entire minute on end.
                            Finishing a little bit before it does, you rise to your feet.
                            Noticing you've stopped drinking, it follows suit, seemingly standing at attention, awaiting your next [i]command[/i].
                            But no order comes.
                            You have no interest in being the creature's master.
                            You just want to get out of here already.
                        [/p]
                        [p]
                            You start following the river-branch, hoping it'll lead you to some kind of exit.
                            The monster tags along, scuttling after you, like a trained dog that doesn't even need a leash to know its place.
                            Not feeling threatened by it, you take your time to leisurely stroll alongside the water, until daylight comes into sight.
                            As you expected: it was a stale branch of the river!
                            Climbing out of the cave, you sit your butt down on the riverside dirt, and take a breather.
                            You feel like you've earned one.
                        [/p]
                        [p]
                            The basilisk, which followed you until the cave-entrance, stares at your seated frame from the darkness of the cavern's interior.
                            It seems [b]scared[/b] of the sunlight, perhaps unable to weather it.
                            You give it a dismissive wave, wordlessly ordering it to go back home.
                            It utters a loud whine, hesitating to follow your command,
                            but after a bit of what you can only imagine to be [i]pouting[/i],
                            the creature rejectedly turns its tail, and saunters back into its lair. 
                        [/p]
                        [p]
                            You could have used a basilisk companion, especially one that knows its place.
                            But since it can't travel during the day,
                            and seeing as you'd have a hard time explaining to the guards of Varanar why you're trying to bring a [b]lethal beast[/b] into the city at night,
                            you figure it'd be best to leave the monster here.
                            It's better off without you anyway.
                            Around you, it'd just end up getting killed.
                            Besides, you can barely even scrounge up enough food to feed yourself,
                            let alone a feral several times your weight.
                        [/p]
                        [p]
                            You've defied death more than once today.
                            You should consider yourself lucky to be alive.
                            The trip into the well was a harrowing experience.
                            You nearly got crushed, almost drowned, and after all of that, you managed to wrestle and tame a basilisk.
                            You doubt there's other kobolds that can claim they tussled with a mythological beast and [b]won[/b].
                        [/p]
                        [p]
                            You've gained a few awesome stories to tell once you've grown old and wise.
                            Stories like the ones Seki used to tell you when you were little.
                            You went through all that trouble to get your mind off of him, and here you are reminiscing once more.
                            You just can't help yourself from clinging to times long gone.
                            Things were so much simpler back then.
                            You miss those days.
                        [/p]
                        [p]
                            The sun is slowly starting to set.
                            You drag yourself to your feet.
                            It's time to go.
                            Varanar isn't [i]that[/i] far off.
                            If your legs don't give out from underneath you, you might still make it there before nightfall.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
