/**
 * To bed section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeHideToBed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var toWake = new HomeHideWakeUp(ctrl);

    var continueId = `homeHideBedContinue`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You lie there for a few more hours.
                            You are conscious, yet your body is crippled with pain.
                            You slowly rock back and forth in your fetal position, more than a little traumatized.
                            You've never quite been brutalized like that before.
                            The entire ordeal has left you mentally [b]demolished[/b].
                        [/p]
                        [p]
                            Your face hurts.
                            Your stomach hurts.
                            Your [b]everything[/b] hurts.
                            You bring your hands to your visage.
                            The swelling seems to have gone down a bit, enough for you to open your eyes.
                            The sun has set, and night-time is upon you.
                        [/p]
                        [p]
                            You slowly unfurl from your self-protecting posture.
                            You are shivering, not just from your poor mental condition, but from being cold.
                            You rise to your unsteady feet, wiping some of the blood off of your muzzle.
                        [/p]
                        [p]
                            At least...at least there's one thing that can offer you [i]some[/i] solace.
                            You limp away from your shed, stopping at a familiar tree and dropping to your knees.
                            You dig rampantly, with both your hands, uncovering your well-hidden stash of gold.
                            You press the dirt-covered coin pouch against your chest, cradling it.
                            Your near-[b]broken[/b] mind [b]needs[/b] something to cling to.
                            Your plan [b]worked[/b], or so you claim, to keep yourself from falling apart.
                        [/p]
                        [p]
                            A small smile forms upon your disfigured face, 
                            but it quickly fades to tears once more as you fail to hold up the pretense for more than a few moments.
                            The horrible pain you're in is [b]not[/b] worth [b]any[/b] amount of gold,
                            but you wish you didn't have to realize that cold, hard fact.
                        [/p]
                        [p]
                            You stagger back towards your home.
                            You push open your shed's wooden door.
                            After closing it behind you, you fall down on top of the bale of hay that you call your [i]bed[/i].
                            Still clutching your filthy purse, you slowly cry your battered form to sleep, hoping you'll wake up in the morning.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.hide.sleepContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.hide.sleepContinue();
            loadNextPart(toWake);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHideBed";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.hide.ballContinued()) {
            return "";
        }
        global.ui.applyTheme("home_night");
        var change = ctrl.saved.hide.sleepChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toWake.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.hide.ballContinued()) {
            return;
        }
        
        toWake.registerListeners();

        if (ctrl.saved.hide.sleepContinued()) {
            return;
        }

        registerContinueListener();
    };
}
