/**
 * End section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorDodgeSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.dodgeSucceed;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            A jar of oil?
                            A simple sidestep should suffice to avoid that!
                            You don't need to dive all the way to the ground.
                            All you need to do is move to the side a little, and he'll miss.
                            You're sure of it!
                            Preparing to evade, you continue heading for the door.
                            The human, predictably, hurls the heavy pot your way.
                        [/p]
                        ${global.ui.condSucc(`Agility greater than 6`)}
                        [p]
                            Using your superior agility, you hop to the left mid-stride, dodging without even stopping!
                            The jar, which turns out to be empty, misses you by mere inches,
                            cracking open against the wall instead, breaking into a million little pieces.
                            Seems like you were too fast for the slow brute to handle!
                            You run through the dust-cloud of debris, sprinting out the door and into the streets, vanishing amidsts the slums.
                            A few minutes of rapid jogging later, you come to an exhausted standstill, somewhere amidsts the mercantile district of the city.
                            Confident that you've shaken off your pursuer, you sit yourself down against a nearby building, and catch your breath.
                        [/p]
                        [p]
                            Your left hand hurts like hell.
                            The lacerated cut isn't as bad as you thought it was, but it's pretty darn painful.
                            You think something internally might be broken or shattered, but you retain full control over all of your fingers,
                            so you're not really too concerned about it.
                            The pain'll fade, in time.
                            Or so you hope.
                        [/p]
                        [p]
                            You rise to your feet once more.
                            The sun is slowly starting to set.
                            The afternoon is turning into a dark and cold winter evening.
                            It's time to figure out where you're going to sleep.
                            Your wounds will heal overnight.
                            And if they don't, there's always tomorrow.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
