/**
 * Fail section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorFailFlee(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = AfternoonThreeParlorFailChoicesChoice.FLEE;
    var reqController = ctrl.fail;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You may be beaten, but you are not yet broken.
                            Thinking you spy an opportunity for escape, you run into the lobby as fast as your malnourished legs can carry you.
                            Your mad dash for freedom is cut short less than a dozen steps in,
                            your pace not nearly as quick as you'd hoped for,
                            your body far too battered to burst into a sprint.
                        [/p]
                        [p]
                            Tychus [b]grabs[/b] you by the back of your neck, painfully lifting you off the ground.
                            "[color=purple]You want to go outside? Then let's go.[/color]"
                            The human carries you out of the building, using your body to push open the wooden door,
                            a few splinters agonizingly burying into your lash-marks.
                        [/p]
                        [p]
                            Outside, you can barely see.
                            The rain hits your scales.
                            It reminds you of how things used to be, back home in the forest.
                            A small smile forms on your tortured face.
                            Is this heaven?
                            Did you finally die?
                        [/p]
                        [p]
                            No.
                            Not yet.
                            You are thrown to the ground.
                            "[color=purple]You were trouble right from the start.
                            I shouldn't have wasted my time on you.[/color]"
                            That said, Tychus lifts up his heavy boot, and [b]stomps[/b] down on your leg.
                            A loud, sickening [b]snap[/b] reverberates across the empty slum-streets,
                            louder than the splashing of the raindrops on the rooftops and the dirt road.
                            Gut-wrenching pain, a thousand times worse than the whippings makes every passing moment a living hell.
                        [/p]
                        [p]
                            You [b]beg[/b] for mercy, but it's too late.
                            The human has made his decision.
                            A second time, his boot comes down, your other leg broken in the same fashion as the first.
                            You throw up what little contents you stomach has, the pain too much to bear.
                            Accidentally, while trying to look Tychus in the eyes, you gaze up at the sky, bright enough to [b]scorch[/b] your retinas.
                        [/p]
                        [p]
                            A sharp [b]kick[/b] to your already hurting chest snaps you out of your near-delirious state.
                            "[color=purple][b]CRAWL, slave.[/b]
                            And if you [b]dare[/b] stop before you're out of my sight,
                            then I'll break [b]every[/b] last bone in your body before allowing you to [b]die[/b].[/color]"
                        [/p]
                        [p]
                            Half-dead already, you dig your claws into the dirt, and you begin to crawl.
                            Blinded, crippled, in so much pain you can barely breathe, you crawl through the cold, muddy dirt.
                            You don't know where you're going.
                            You don't care.
                            As long as it's away from [b]him[/b].
                            You leave a trail of blood in your wake, quickly washed away by the rain.
                            You cough up even more blood.
                            Something inside you broke.
                        [/p]
                        [p]
                            You need help.
                            You whimper, beg and plead, but nobody is around to hear you.
                            Your arms are getting tired.
                            You can't feel your tail.
                            You lower your head into the mud.
                            Your heavy breathing slows down to a crawl.
                            And then it stops, forever more.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    Gutter end.
                                [/b]
                            [/c]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" style="margin-left: auto; position: relative; float: right;" id="${continueId}">`;
        choice += `&lt;&lt Revert`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bgm.stopLoop();
            ctrl.reset();
            ctrl.reload();
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        registerContinueListener();
    };
}
