/**
 * Knockout section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorEscapeRopesSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preMasseuse;
    var changeController = ctrl.escape;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.masseuse;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var footMassage = global.kobold.history.shared.varanar.dayThree.afternoon.parlorFootMassage;
        var toReturn = `[p]
                            These ropes aren't so tightly tied.
                            You reckon you can slip free without needing to pry the cord itself apart!
                            Wriggling your wrist about, you begin to try to rid yourself of your bindings.
                        [/p]
                        ${global.ui.condSucc(`Agility greater than 6`)}
                        [p]
                            You try tugging, twisting, pulling, sliding and contorting your hand in all manners possible,
                            but you simply can not escape the thick rope binding your wrists.
                            It's too tight around your scales,
                            and the coarse fabric the rope is made of kind of [i]hurts[/i] whenever you attempt to escape it.
                            Like rope burn, but a little [b]worse[/b].
                        [/p]
                        [p]
                            Then you notice the rope around your left foot is a little slack.
                            Perhaps you've been going about this all wrong.
                            It isn't your hand you should try to wriggle free, but your foot!
                            You begin to contort your ${footMassage ? `freshly massaged` : ``} scaly trotter,
                            and after some near-dislocating feats of flexibility, you manage to slip your foot free from its bondage!
                        [/p]
                        [p]
                            One foot free, three limbs to go.
                            First, you free your other foot.
                            Untying the knot using your toes is an easy task for a thief as skilled as you are.
                            Then, using your superior agility, you arch your back, curling up and maneuvering your foot to your head,
                            before angling slightly to the side, bringing your clawed toes to bear on the rope holding your hand.
                            After freeing one of your hands, untying the other is child's play.
                        [/p]
                        [p]
                            You rid yourself of the last piece of rope dangling off your wrist, and sneak over to one of the two doors.
                            Opening it, you discover that the room you were in was adjacent to the massage room.
                            Orange is tidying up the place, sweeping the floor, probably removing any trace that were ever even here.
                            As if anyone would come looking for [i]you[/i].
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
