/**
 * Masseuse section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorMasseuseBluffSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preItemGet;
    var changeController = ctrl.bluff;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.itemGet;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            She hasn't noticed you yet.
                            That gives you the element of surprise.
                            But if you [i]surprise[/i] her, she might scream for help.
                            Hm, your best course of action would be to talk her down, but first you need to make your presence clear somehow.
                            You think you have an idea that [i]might[/i] work.
                        [/p]
                        [p]
                            You creep forwards, sneaking behind Orange.
                            She's finished sweeping, and is now dusting off a few racks.
                            You approach her, unseen and unheard.
                            Then, striking from the shadows, you grab her muzzle from behind, silencing her while keeping her in place.
                            She instantly struggles against your grasp.
                            You tell her to stay calm, that you're not going to hurt her.
                            You just want to talk.
                        [/p]
                        ${global.ui.condSucc(`Charisma greater than 5`)}
                        [p]
                            Orange slightly calms down, ceasing her attempts to shake you off.
                            You tell her that you're going to let go of her mouth now, but she has to promise not to scream.
                            Removing your hand from her muzzle, you're glad to see that she [b]doesn't[/b] rat you out to Tychus.
                            At least not right away.
                        [/p]
                        [p] 
                            You ask the masseuse why she knocked you out.
                            What's going on here?
                            Does Tychus treat all of his customers this way?
                            She speaks, in a hushed tone, as to not alert her [i]master[/i].
                            "[color=orange]No, only the kobolds.
                            I was the first.
                            The other three were like you, once.
                            They came in here for a massage, and they never left.[/color]"
                        [/p]
                        [p]
                            But why?
                            You mean, you can see why Tychus would prefer slave labor over actually having to [i]pay[/i] his employees,
                            but why does she play along with all of this?
                            What's in it for her?
                            Orange masterfully breaks your hold on her, swinging you around,
                            turning the entire situation on its head, pressing [b]you[/b] against the wall, pinning your throat with her lower arm.
                            She stares into your eyes with a hateful glare.
                        [/p]
                        [p]
                            While obviously upset, her voice remains somewhat even and level.
                            "[color=orange]Do you think I [b]want[/b] to be a part of this?
                            He was going to [b]kill me[/b] if I didn't do his bidding.
                            Heck, he'll kill us [b]both[/b] if he sees me talking to you.[/color]"
                            Orange lets go of your throat, and takes a few steps back.
                            Tears start to form at the corners of her hate-filled eyes.
                        [/p]
                        [p]
                            "[color=orange]I'm sorry, for what it's worth.
                            If not me, he'd have bought another slave to do his dirty work.
                            I couldn't stop it, not even by letting him kill me.
                            So I did the only thing I could.
                            I served.[/color]"
                        [/p]
                        [p]
                            You say you understand.
                            She did what she had to.
                            But you can't stay here.
                            And neither can she.
                            She needs to come with you.
                            You'll escape, together.
                            Maybe you can even come back for the others, later.
                            You extend your hand, hoping she'll take it, hoping she'll see reason.
                        [/p]
                        [p]
                            But she doesn't.
                            Orange shakes her head no.
                            Her tears drop to the ground.
                            She slowly starts to back away, towards the room you emerged from.
                            "[color=orange]It's too late for me.
                            The things I've done can [b]never[/b] be forgiven.
                            I've ruined more lives than my own.
                            I can't live with the guilt.
                            Not anymore.[/color]"
                        [/p]
                        [p]
                            You tell her that it'll be okay.
                            [b]You[/b] forgive her.
                            You're sure the others will, too.
                            You can help her.
                            It's not too late for her to redeem herself!
                            It's [b]never[/b] too late!
                            But your words are wasted.
                            She doesn't listen.
                            She's reached the entrance to the backroom.
                            She slips inside, but doesn't close the door quite yet.
                        [/p]
                        [p]
                            Orange gives you a few final words of advice:
                            "[color=orange]Run.
                            Run and [b]never[/b] look back.
                            Save yourself.
                            There's nothing left worth fighting for here.
                            I'm sorry for everything.
                            I won't be a burden anymore.
                            Thank you.
                            Goodbye.[/color]"
                        [/p]
                        [p]
                            With those words said, she closes the door, audibly locking it behind her.
                            And that is the last you ever see of Orange.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
