/**
 * Arrival section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreArrival(controller) {
// PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;
    var autoContinue = false;
    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreProposal(ctrl);
    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        // Log to prevent early overwriting
        ctrl.misc.oralVirgin();
        ctrl.misc.analVirgin();
        ctrl.misc.cuntVirgin();
        ctrl.misc.weapon();
        
        var stole = global.kobold.history.shared.varanar.dayThree.noon.stole;
        var gaveHouse = global.kobold.history.shared.varanar.dayThree.noon.gaveHouse;
        var comforted = global.kobold.history.shared.varanar.dayThree.noon.comforted;
        var donated = global.kobold.history.shared.varanar.dayThree.noon.donated;

        var toReturn = ``;
        if (stole) {
            toReturn += `[p]
                            For the better part of an hour, you conceal yourself within the droves of people crowding the grand avenue,
                            blending in as best you can, trying to look like an [i]ordinary[/i] window-shopping kobold and [b]not[/b] a thief on the run.
                            As time goes by, your deceit slowly turns to reality, your wariness about being [i]caught[/i] fading,
                            replaced by a genuine curiosity in the stores you're admiring.
                        [/p]`;
        } else {
            toReturn += `[p]`;
            if (gaveHouse || donated) {
                toReturn += `A good deed done, you head for the grand avenue.`;
            } else if (comforted) {
                toReturn += `With the sheep [i]comforted[/i], you head for the grand avenue.`;
            } else {
                toReturn += `Your [i]dinner[/i] eaten, you head for the grand avenue.`;
            }
            toReturn += `   While the droves of people crowding the streets make navigating a bit hard for someone of your [i]size[/i],
                            you manage to avoid getting [i]trampled[/i] by sticking close to the edges of the road, away from most of the bustling traffic.
                        [/p]`;
        }

        toReturn += `   [p]
                            Bakeries with pastries, sweet tarts and more bread than you've ever [b]seen[/b] assembled in one place.
                            Butcher shops with more meat on display than you have on your bones.
                            Weapon stores stalling swords and axes and maces taller than you are.
                            Armor smithies displaying full sets of plate that could fit you twice and more.
                        [/p]
                        [p]
                            Beautiful, imposing, alluring sights, to say the least.
                            Alas, most of the things you see are [i]out of reach[/i].
                            You have no way of being able to actually [i]afford[/i] a lot of this stuff.
                            Aside from [i]stealing[/i] or being [i]awarded[/i] a set, you'll [b]never[/b] know what it feels like to own plate armor.
                            And good luck trying to steal something that weighs more than you do.
                            Besides, you doubt kobold-sized suits of armor even [i]exist[/i].
                        [/p]
                        [p]
                            After browsing the various shops for a good bit,
                            you come to a halt in front of a place that looks a bit more [i]affordable[/i].
                            A general store, by the name of [b]Rolande's Wares and Tears[/b],
                            according to a small sign hanging off a wooden beam above the door.
                            From what you can see through the window, this place appears to stock a large array of things,
                            from daily necessities to travelling gear and even a wide selection of potions!
                            ${ctrl.misc.gold() ? `Surely, you'll be able to at least afford a string of rope
                            or something` : `Even [i]if[/i] you have no money, there's no harm in taking a look inside`}, right?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;
    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };
    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();
        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
