/**
 * Return section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreReturn(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.return;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreReturnLeave(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var noWhore = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.DECLINE;
        var oldWeapon = ctrl.misc.weapon();
        var greatsword = ctrl.postShopMisc.weapon();
        var toReturn = `[p]
                            Your purchases complete, you head towards the store's entrance,
                            dragging your brand spanking new ${global.kobold.inventory.createItemWithTooltip(greatsword)} behind you.
                            This thing is [b]heavy[/b].
                            You can barely even [b]lift it[/b], let alone swing it around in battle.
                            You think you made a mistake buying this.
                            Trying your hardest to not let the sharpened steel trail along the wooden floor, you walk back towards the counter.
                        [/p]
                        [p]
                            "[color=yellow]What now, kobold?
                            Spit it out already.
                            An actual customer might walk in any second now and see me catering to [i]your[/i] kind.[/color]"
                            You say that you kind of didn't really think this whole zweihander thing through.
                            You really can't use this weapon.
                            You'd like a refund, if at all possible?
                        [/p]
                        [p]
                            "[color=yellow][b]Refund[/b]?!
                            Hah!
                            I don't deal in second hand goods.[/color]"
                            You mention that practically [b]everything[/b] in the corner you shopped from looked second hand, to some degree.
                            "[color=yellow]Ugh.
                            [b]Fine[/b].
                            I'll give you [b]fifty[/b] coins for it.[/color]"
                            Fifty?!
                            But that's [b]way[/b] less what you paid for it just five minutes ago!
                            "[color=yellow]Then don't take my offer, and drag your pretty new sword out the door.[/color]"
                        [/p]
                        [p]
                            You sigh loudly.
                            Bloody merchants, always squeezing money out of people whenever they can.
                            At least fifty coins is better than nothing.
                            You reluctantly accept the dragon's offer.
                            Handing over your oversized weapon, he returns a fraction of what you paid for it.
                            ${oldWeapon ? `"[color=yellow]Here.
                            As an added bonus, I even saved [b]this[/b] for you.
                            You dropped it earlier.[/color]"
                            To your surprise, Rolande hands you back your [b]previous[/b] weapon,
                            your good old trusty ${global.kobold.inventory.createItemWithTooltip(oldWeapon)}.
                            Perhaps he's not such a terrible person after all.` : ``}
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
