/**
 * Flee section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoRunGetaway(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NightTwoRunGetawayContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Desperate to get away from the men, you burst into a sprint the moment you turn a corner,
                            hoping to be able to outrun them before they even [i]know[/i] you're escaping.
                            While your gambit does pay off in the form of a head start, sadly, you don't manage to shake the group from the get-go.
                            Noticing their lizard-prey running away,
                            the men drop their tight-packed group-cohesion and begin to outright [b]chase[/b] after you.
                        [/p]
                        [p]
                            You run from street to street, periodically checking behind you to make sure they haven't given up yet.
                            While far bigger than you, and probably able to outrun you whilst sober, their heavy inebriation hinders the belligerent group significantly.
                            A couple of pursuers tumble over their own feet, falling to the ground, being left behind by their peers.
                            A few of the men get too sick to keep pursuing you, retreating into alleyways to empty their bellies of food and drink.
                            Some of them are simply too weary to keep up pursuit.
                            Initially numbering high in the single-digits,
                            it takes only a few solid minutes of running for their [i]pack[/i] to be reduced to three hard-boiled men.
                        [/p]
                        [p]
                            But still, even just [b]one[/b] of them can [b]cave your head in[/b] if they manage to catch you.
                            You aren't out of the woods until you can shake off [b]all three[/b] of them.
                            And you get the feeling that all this running is making them [b]even more frustrated[/b].
                            There's no doubt in your mind: your very life is at stake here.
                            And the humans chasing you are [b]determined[/b] to rid their city of another [b]pest[/b] infesting it.
                        [/p]
                        [p]
                            You push your body to its very limits, sprinting away as fast as you can.
                            Your legs are rapidly growing weary, but so are theirs, you hope.
                            Crossing into a more dignified area of Varanar, one of the few districts with cobblestone roads,
                            you almost lose your balance as the flat dirt under your feet suddenly makes way for a more uneven, rock-like surface.
                            [i]Almost[/i].
                        [/p]
                        ${global.ui.condSucc(`Sufficient stamina`)}
                        [p]
                            Luckily, it seems like the men chasing you, too, have difficulty adapting to the new enviroment.
                            Looking behind you, you can see one of them taking a particularly [b]nasty[/b] dive, his forehead [b]slamming[/b] into the rocky ground.
                            You're pretty sure you can hear something [b]crack[/b], although you don't know whether it's his skull or the street he fell atop.
                            Either way, the man's [i]friends[/i] cease their pursuit in order to tend to their fallen comrade, who seems [b]seriously[/b] hurt.
                            Serves him right for chasing you!
                        [/p]
                        [p]
                            While no longer being tailed, you maintain a hasty pace,
                            crossing a few more streets on sheer adrenaline alone to ensure the hoodlums won't catch you.
                            Not tonight, at least.
                            Once you're [b]completely[/b] certain you've lost them, you slowly come to a halt,
                            leaning against a nearby building to keep your overexerted body upright.
                            You catch your breath, your loud panting resonating across the otherwise empty street.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.runGetaway.continued() ? "disabled" : "";
        var isSelected = ctrl.runGetaway.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.runGetaway.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.runGetaway.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        next.registerListeners();

        if (ctrl.runGetaway.continued()) {
            return;
        }

        registerNextListener();
    };
}
